pub struct LogStore { /* private fields */ }Available on crate feature
store only.Expand description
Thread-safe append-only in-memory log store.
The store keeps all captured entries in memory until it is dropped. It does not apply retention, eviction, or size limits.
Implementations